@@ -34,17 +34,39 @@ API::API(const std::string& token, const std::string& secret)
     curl_easy_setopt(curlhandle, CURLOPT_NOPROGRESS, 1);
     curl_easy_setopt(curlhandle, CURLOPT_PROGRESSDATA, this);
     curl_easy_setopt(curlhandle, CURLOPT_FAILONERROR, true);
+    curl_easy_setopt(curlhandle, CURLOPT_NOSIGNAL, 1);
 
     this->error = false;
     this->config.oauth_token = token;
     this->config.oauth_secret = secret;
 }
 
+/* Initialize the API
+    returns 0 if failed
+    returns 1 if successful
+*/
 int API::init()
 {
     int res = 0;
+
     this->getAPIConfig();
 
+    if (!this->getError())
+        res = 1;
+    else
+        this->clearError();
+
+    return res;
+}
+
+/* Login check
+    returns false if not logged in
+    returns true if logged in
+*/
+bool API::isLoggedIn()
+{
+    int res = 0;
+
     // Check if we already have token and secret
     if (!this->config.oauth_token.empty() && !this->config.oauth_secret.empty())
     {
@@ -55,7 +77,6 @@ int API::init()
     return res;
 }
 
-
 int API::getAPIConfig()
 {
     std::string url = "https://api.gog.com/downloader2/status/stable/"; // Stable API
